@@ -12,9 +12,9 @@ fn main() {
     // Since we are generating completions in the package directory, we need to set this so that
     // Cargo doesn't rebuild every time.
     println!("cargo:rerun-if-changed=build.rs");
-    println!("cargo:rerun-if-changed=src");
-    println!("cargo:rerun-if-changed=templates");
-    println!("cargo:rerun-if-changed=tests");
+    println!("cargo:rerun-if-changed=src/");
+    println!("cargo:rerun-if-changed=templates/");
+    println!("cargo:rerun-if-changed=tests/");
 
     generate_completions().unwrap();
 }
