@@ -1,8 +1,13 @@
-mod app;
+#![allow(clippy::single_component_path_imports)]
+
+// rstest_reuse must be imported at the top of the crate.
+#[cfg(test)]
+use rstest_reuse;
+
+mod cmd;
 mod config;
 mod db;
 mod error;
-mod fzf;
 mod shell;
 mod util;
 
@@ -11,7 +16,7 @@ use std::{env, process};
 
 use clap::Parser;
 
-use crate::app::{App, Run};
+use crate::cmd::{Cmd, Run};
 use crate::error::SilentExit;
 
 pub fn main() {
@@ -19,7 +24,7 @@ pub fn main() {
     env::remove_var("RUST_LIB_BACKTRACE");
     env::remove_var("RUST_BACKTRACE");
 
-    if let Err(e) = App::parse().run() {
+    if let Err(e) = Cmd::parse().run() {
         match e.downcast::<SilentExit>() {
             Ok(SilentExit { code }) => process::exit(code),
             Err(e) => {
