@@ -39,11 +39,11 @@ enum App {
 }
 
 trait CommandExt {
-    fn _run(self) -> Result<()>;
+    fn run(self) -> Result<()>;
 }
 
 impl CommandExt for &mut Command {
-    fn _run(self) -> Result<()> {
+    fn run(self) -> Result<()> {
         println!(">>> {:?}", self);
         let status = self.status().with_context(|| format!("command failed to start: {:?}", self))?;
         if !status.success() {
@@ -54,9 +54,8 @@ impl CommandExt for &mut Command {
 }
 
 fn run_ci(nix_enabled: bool) -> Result<()> {
-    let color: &[&str] = if is_ci() { &["--color=always"] } else { &[] };
-    Command::new("cargo").args(&["check", "--all-features"]).args(color)._run()?;
-
+    // Run cargo-clippy.
+    Command::new("cargo").args(&["clippy", "--all-features", "--all-targets"]).args(&["--", "-Dwarnings"]).run()?;
     run_fmt(nix_enabled, true)?;
     run_lint(nix_enabled)?;
     run_tests(nix_enabled, "")
@@ -64,9 +63,8 @@ fn run_ci(nix_enabled: bool) -> Result<()> {
 
 fn run_fmt(nix_enabled: bool, check: bool) -> Result<()> {
     // Run cargo-fmt.
-    let color: &[&str] = if is_ci() { &["--color=always"] } else { &[] };
     let check_args: &[&str] = if check { &["--check", "--files-with-diff"] } else { &[] };
-    Command::new("cargo").args(&["fmt", "--all", "--"]).args(color).args(check_args)._run()?;
+    Command::new("cargo").args(&["fmt", "--all", "--"]).args(check_args).run()?;
 
     // Run nixfmt.
     if nix_enabled {
@@ -75,7 +73,7 @@ fn run_fmt(nix_enabled: bool, check: bool) -> Result<()> {
             let path = entry.path();
             if path.is_file() && path.extension() == Some(OsStr::new("nix")) {
                 let check_args: &[&str] = if check { &["--check"] } else { &[] };
-                Command::new("nixfmt").args(check_args).arg("--").arg(path)._run()?;
+                Command::new("nixfmt").args(check_args).arg("--").arg(path).run()?;
             }
         }
     }
@@ -84,25 +82,16 @@ fn run_fmt(nix_enabled: bool, check: bool) -> Result<()> {
 }
 
 fn run_lint(nix_enabled: bool) -> Result<()> {
-    // Run cargo-clippy.
-    let color: &[&str] = if is_ci() { &["--color=always"] } else { &[] };
-    Command::new("cargo")
-        .args(&["clippy", "--all-features", "--all-targets"])
-        .args(color)
-        .args(&["--", "-Dwarnings"])
-        ._run()?;
-
     if nix_enabled {
         // Run cargo-audit.
-        let color: &[&str] = if is_ci() { &["--color=always"] } else { &[] };
-        Command::new("cargo").args(&["audit", "--deny=warnings"]).args(color)._run()?;
+        Command::new("cargo").args(&["audit", "--deny=warnings"]).run()?;
 
         // Run markdownlint.
         for result in Walk::new("./") {
             let entry = result.unwrap();
             let path = entry.path();
             if path.is_file() && path.extension() == Some(OsStr::new("md")) {
-                Command::new("markdownlint").arg(path)._run()?;
+                Command::new("markdownlint").arg(path).run()?;
             }
         }
 
@@ -111,7 +100,7 @@ fn run_lint(nix_enabled: bool) -> Result<()> {
             let entry = result.unwrap();
             let path = entry.path();
             if path.is_file() && path.extension() == Some(OsStr::new("1")) {
-                Command::new("mandoc").args(&["-man", "-Wall", "-Tlint", "--"]).arg(path)._run()?;
+                Command::new("mandoc").args(&["-man", "-Wall", "-Tlint", "--"]).arg(path).run()?;
             }
         }
     }
@@ -120,13 +109,8 @@ fn run_lint(nix_enabled: bool) -> Result<()> {
 }
 
 fn run_tests(nix_enabled: bool, name: &str) -> Result<()> {
-    let color: &[&str] = if is_ci() { &["--color=always"] } else { &[] };
-    let features: &[&str] = if nix_enabled { &["--all-features"] } else { &[] };
-    Command::new("cargo").args(&["test", "--no-fail-fast", "--workspace"]).args(color).args(features).arg(name)._run()
-}
-
-fn is_ci() -> bool {
-    env::var_os("CI").is_some()
+    let args: &[&str] = if nix_enabled { &["nextest", "run", "--all-features"] } else { &["test"] };
+    Command::new("cargo").args(args).args(&["--no-fail-fast", "--workspace", "--", name]).run()
 }
 
 fn enable_nix() -> bool {
@@ -136,7 +120,6 @@ fn enable_nix() -> bool {
     }
     let nix_enabled = env::var_os("IN_NIX_SHELL").unwrap_or_default() == "pure";
     if nix_enabled {
-        env::set_var("CARGO_TARGET_DIR", "target_nix");
         return true;
     }
     let nix_detected = Command::new("nix-shell").arg("--version").status().map(|s| s.success()).unwrap_or(false);
